/* Patchwork database schema
 * version 0.1
 * 	for MySQL databases
 */
begin;

CREATE TABLE person (
	id		INTEGER NOT NULL AUTO_INCREMENT,
	email		VARCHAR(250) NOT NULL,
	name		TEXT NULL,

	PRIMARY KEY (id),
	UNIQUE (email)
) TYPE = InnoDB;
CREATE INDEX person_email_idx ON person (email);
GRANT SELECT ON person TO "www-data";
GRANT SELECT,INSERT,UPDATE ON person TO nobody;

CREATE TABLE `user` (
	id		INTEGER NOT NULL,
	username	VARCHAR(64) NOT NULL,
	passwd		CHAR(32),

	PRIMARY KEY(id),
	FOREIGN KEY (id) REFERENCES person (id),
	UNIQUE(username)
) TYPE = InnoDB;
GRANT SELECT ON `user` TO "www-data";

CREATE TABLE state (
	id		INTEGER NOT NULL AUTO_INCREMENT,
	name		TEXT NOT NULL,
	ordering	INTEGER NOT NULL,

	PRIMARY KEY (id),
	UNIQUE (ordering)
) TYPE = InnoDB;
GRANT SELECT ON state TO "www-data";

CREATE TABLE patch (
	id		INTEGER NOT NULL AUTO_INCREMENT,
	msgid		VARCHAR(250) NOT NULL,
	name		TEXT NOT NULL,
	date		TIMESTAMP NOT NULL,
	submitter	INTEGER NOT NULL,
	state		INTEGER NOT NULL DEFAULT 1,
	archived	TINYINT(1) NOT NULL DEFAULT 0,
	filename	TEXT NOT NULL,
	content		TEXT NOT NULL,

	PRIMARY KEY (id),
	KEY (submitter),
	KEY (state),
	FOREIGN KEY (submitter) REFERENCES person (id),
	FOREIGN KEY (state) REFERENCES state (id)
) TYPE = InnoDB;
CREATE INDEX patch_msgid_idx ON patch (msgid);
GRANT SELECT,UPDATE,DELETE ON patch TO "www-data";
GRANT SELECT,INSERT ON patch TO nobody;

CREATE TABLE comment (
	id		INTEGER NOT NULL AUTO_INCREMENT,
	patch		INTEGER NOT NULL,
	msgid		TEXT NOT NULL,
	submitter	INTEGER NOT NULL,
	date		TIMESTAMP NOT NULL,
	content		TEXT NOT NULL,

	PRIMARY KEY (id),
	KEY (patch),
	KEY (submitter),
	FOREIGN KEY (patch) REFERENCES patch (id) ON DELETE CASCADE,
	FOREIGN KEY (submitter) REFERENCES person (id)
) TYPE = InnoDB;
CREATE INDEX comment_patch_idx ON comment (patch);
GRANT SELECT ON comment TO "www-data";
GRANT INSERT ON comment TO nobody;

CREATE TABLE tree (
	id		INTEGER NOT NULL AUTO_INCREMENT,
	name		TEXT NOT NULL,
	url		TEXT,

	PRIMARY KEY (id)
) TYPE = InnoDB;
GRANT SELECT ON tree TO "www-data";

CREATE TABLE patch_tree (
	patch		INTEGER NOT NULL,
	tree		INTEGER NOT NULL,
	date		TIMESTAMP NOT NULL,

	PRIMARY KEY (patch, tree),
	KEY (patch),
	KEY (tree),
	FOREIGN KEY (patch) REFERENCES patch (id) ON DELETE CASCADE,
	FOREIGN KEY (tree)  REFERENCES tree (id)  ON DELETE CASCADE
) TYPE = InnoDB;
GRANT SELECT,INSERT,DELETE ON patch_tree TO "www-data";

commit;
