#!/usr/bin/perl -w
#
# Patchwork - automated patch tracking system
# Copyright (C) 2005 Jeremy Kerr <jk@ozlabs.org>
#
# This file is part of the Patchwork package.
#
# Patchwork is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Patchwork is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Patchwork; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

use strict;
use lib '../lib';

use PatchWork::SiteConfig;
use PatchWork::PatchDatabase;
use Getopt::Long;
use Term::ReadKey;

my $configname;

exit 1 unless GetOptions('config=s' => \$configname);
$ENV{PATCHWORK_CONFIG} = $configname if $configname;
my $config = new PatchWork::SiteConfig() or die "No such config $configname";
my $db = new PatchWork::PatchDatabase($config);

sub get_value(@)
{
	my ($name, $hide) = @_;	

	printf("$name: ");
	ReadMode('noecho') if $hide;
	my $buf = ReadLine(0);
	ReadMode('restore') if $hide;
	print "\n" if $hide;
	chomp $buf;
	return $buf;
}

my $username = (shift(@ARGV) or get_value('Username'));
my $name = (shift(@ARGV) or get_value('Name'));
my $email = (shift(@ARGV) or get_value('Email'));
my $password = get_value('Password', 1);
die "Passwords differ" unless $password eq get_value('Repeat Password', 1);

my $user = new PatchWork::User(0);
$user->username($username);
$user->email($email);
$user->name($name);
$db->add_user($user, $password);
