#!/usr/bin/perl -wT
#
# Patchwork - automated patch tracking system
# Copyright (C) 2005 Jeremy Kerr <jk@ozlabs.org>
# - Modified by David Howells <dhowells@redhat.com>
#
# This file is part of the Patchwork package.
#
# Patchwork is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Patchwork is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Patchwork; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

use strict;
use lib '../lib';

use PatchWork::SiteConfig;
use PatchWork::PatchDatabase;
use PatchWork::Web;
use PatchWork::Web::Auth;

my $config = new PatchWork::SiteConfig() or die "Couldn't load configuration";
my $w = new PatchWork::Web($config);
$w->authenticate(1);

sub error($)
{
	my ($errstr) = @_;
	print $w->header('Error Updating Patch');
	print '<p>'.$errstr.'</p>';
	print $w->footer();
	exit;
}

my $patch = $w->db->get_patch($w->params('id'));
error("Patch not found") unless $patch;

my $patchfile = $patch->patchfile();
my $submission = $patchfile->submission();

my $redir_to = sprintf("patch.pl?id=%d", $patch->id());

my $action = lc($w->params('action'));

if ($action eq 'update') {
	# at present, all we change is that patch's state ...
	$patch->state($w->params("state"));
	$patch->archived($w->params("archived"));
	$patch->project($w->db->lookup_project_id($w->params("project")));

	# ... and the trees it's in
	$w->db->find_patch_trees($patch);

	my %trees;
	foreach my $tree (values %{$w->db->trees()}) {
		if ($w->param('tree:' . $tree->id())) {
			$trees{$tree->id()} = $tree;
		}
	}

	$w->db->begin();
	$w->db->update_patch_trees($patch, \%trees);

	# change the primary bug report link if necessary
	my $bugtype = $w->params("bugtype");
	my $bugref = $w->params("bugref");

	my $bug = $patch->bug();
	if (!$bugtype || !$bugref) {
		$bug = undef;
	}
	elsif (!$bug || $bug->type() ne $bugtype || $bug->ref() ne $bugref) {
		$bug = new PatchWork::Bug();
		$bug->set(uc($bugtype), $bugref);
	}

	$patch->bug($bug);
	$w->db->insert_bug($bug) if $bug;

	# update the patch
	$w->db->update_patch($patch);

	# done
	$w->db->commit();
}
elsif ($action eq 'delete patch') {
	$w->db->begin();

	# start by deleting the patch of interest and cascade down to
	# patchfile and submission records
	$w->db->delete_patch($patch);

	if ($w->db->count_patches($patchfile) == 0) {
		$w->db->delete_patchfile($patchfile);

		if ($w->db->count_patchfiles($submission) == 0) {
			$w->db->delete_submission($submission);
		}
	}

	# do it
	$w->db->commit();

	# can't go back to that patch now
	$redir_to = "index.pl";

}
else {
	error("Action '$action' specified");
}


printf("Location: %s\n\n", $redir_to);
